==> calligra_3.1.0+dfsg.orig.tar.xz: calligra-3.1.0/components/impl/PresentationImpl.h <==
/*
 * This file is part of the KDE project
 *
 * Copyright (C) 2013 Arjen Hiemstra <ahiemstra@heimr.nl>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef CALLIGRA_COMPONENTS_PRESENTATIONIMPL_H
#define CALLIGRA_COMPONENTS_PRESENTATIONIMPL_H

#include "DocumentImpl.h"

namespace Calligra {
namespace Components {

class PresentationImpl : public DocumentImpl
{
    Q_OBJECT
public:
    explicit PresentationImpl(QObject* parent = 0);
    ~PresentationImpl();
    
    virtual bool load(const QUrl& url);
    virtual int currentIndex();
    virtual void setCurrentIndex(int newValue);
    int indexCount() const;
    virtual QUrl urlAtPoint(QPoint point);
    virtual QObject* part() const;

private:
    class Private;
    Private* const d;
};

} // Namespace Components
} // Namespace Calligra

#endif // CALLIGRA_COMPONENTS_PRESENTATIONIMPL_H

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/components/impl/PresentationImpl.h <==
/*
 * This file is part of the KDE project
 *
 * Copyright (C) 2013 Arjen Hiemstra <ahiemstra@heimr.nl>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef CALLIGRA_COMPONENTS_PRESENTATIONIMPL_H
#define CALLIGRA_COMPONENTS_PRESENTATIONIMPL_H

#include "DocumentImpl.h"

namespace Calligra {
namespace Components {

class PresentationImpl : public DocumentImpl
{
    Q_OBJECT
public:
    explicit PresentationImpl(QObject* parent = 0);
    ~PresentationImpl() override;
    
    bool load(const QUrl& url) override;
    int currentIndex() override;
    void setCurrentIndex(int newValue) override;
    int indexCount() const override;
    QUrl urlAtPoint(QPoint point) override;
    QObject* part() const override;

private:
    class Private;
    Private* const d;
};

} // Namespace Components
} // Namespace Calligra

#endif // CALLIGRA_COMPONENTS_PRESENTATIONIMPL_H
